==> dxf2fig-2.10.tar.gz: dxf2fig-2.10/dxfjplot.c <==
/*
 * DXF2FIG : Converter for Autocad DXF format to FIG format.
 * Aug 1990 : Atari ST and VAX/VMS version by KL
 * Nov 2003 : Modified for Linux and Xfig by KL
 * Copyright (c) 1990-2003 by Kees Lemmens
 *
 * This software is distributed under the Gnu Public License and as such
 * may be copied, redistributed and modified freely as long as the original
 * Copyright above is retained and as long as any software derived from
 * this is distributed under the Gnu Public License as well.  Use of this
 * software in any patented or closed source software is strictly
 * prohibited.
 * 
 * For more information see the GPL : http://www.gnu.org/licenses/gpl.txt
 * 
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <unistd.h>

/* This program uses a modified version of my good old hrgraph library that
 * supports floating point coordinates and changing the datarange, allowing
 * for much more detail than with the old integer based hrgraph library.
 * This jgraph library is however only available in Java and not in the
 * C-based Xaw version, while hrgraph is available for both. */

#include "jgraph.h"
#include "dxfstuff.h"

#define  STAP   0.1
extern   double sin(),cos();

/* Some global (static) variables */

/* End global variables */

#if (DEBUG > 2) /* disable graphics for debug or else debugger may hang */
#  define jdot(x,y)
#  define jplot(x,y)
#  define jsetplot(x,y)
#  define setstyle(s,t)
#endif

long lookupcolor(int color)
{
   switch(color)
    {
     case   0:  return BLACK;    // byblock or white
     case   1:  return RED;      // red
     case   2:  return YELLOW;   // yellow
     case   3:  return GREEN;    // green
     case   4:  return CYAN;     // cyan
     case   5:  return BLUE;     // blue
     case   6:  return MAGENTA;  // magenta
     case   7:  return BLACK;    // black
     case   8:  return WHITE;    // gray          
     case  15:  return WHITE;    // white
     default :  return BLACK;
   }
}

int lookupltype(int ltype)
{
   switch(ltype)
   {
    case  DXFSOLID    :  return SOLID;
    case  DXFDASHED   :  return DASHED;
    case  DXFDOTTED   :  return DOTTED;
    case  DXFDOTDASHED:  return DOTDASHED;
    default           :  return SOLID;
   }
}

int lookuphorjust(int txthjst)
{
   switch(txthjst)
   {
    case  0   :  return TEXTLEFT;
    case  1   :  return TEXTCENTER;
    case  2   :  return TEXTRIGHT;
    default   :  return TEXTLEFT;
   }
}

int getxres()
{
    return 400000;
}

int getyres()
{
   return 300000;
}

void dopoint(Plotdata *d)
{
   debug("Doing Dot ...");

   if( filter(d) > 0) return;
   
   setcolor(DOTCOL,d->rgbcolor);
   jdot(d->xi[0],d->yi[0]);
} 

void doline(Plotdata *d)
{
   debug("Doing Line ...");

   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);

   jsetplot(d->xi[0],d->yi[0]);
   jplot(d->xi[1],d->yi[1]);
}

void dopline(Plotdata *d)
{
   int t;
   
   debug("Doing Polyline with %d vertices, color %d, depth %d ...",
	 d->nrvrt,d->rgbcolor,d->depth);
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   jsetplot(d->xvrt[0],d->yvrt[0]);
   for(t=0;t<d->nrvrt;t++)
     jplot(d->xvrt[t],d->yvrt[t]);
}

void dosolid(Plotdata *d)
{
   debug("Doing Solid ...");

   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);

   jsetplot(d->xi[0],d->yi[0]);
   jplot(d->xi[1],d->yi[1]); jplot(d->xi[3],d->yi[3]);
   jplot(d->xi[2],d->yi[2]); jplot(d->xi[0],d->yi[0]);
}

void do3dface(Plotdata *d)
{
   debug("Doing 3DFace ....");
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   jsetplot(d->xi[0],d->yi[0]);
   jplot(d->xi[1],d->yi[1]); jplot(d->xi[2],d->yi[2]);
   jplot(d->xi[3],d->yi[3]); jplot(d->xi[0],d->yi[0]);
}

void docircle(Plotdata *d)
{  float x;

   debug("Doing Circle ....");
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   /* Note that this routine also plots ellipses in contrast with jcircle() ! */
   
   jsetplot((int)(d->xi[0]+d->rx),d->yi[0]);
   for(x=0;x<PI2;x+=STAP)
     jplot((d->xi[0]+d->rx*cos(x)),
	   (d->yi[0]+d->ry*sin(x)));
   jplot((d->xi[0]+d->rx),d->yi[0]);
}

void doarc(Plotdata *d)
{
   debug("Doing Arc ....");
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   while(d->angle1>d->angle2)
     d->angle1-=PI2;
   d->angle2+=0.5*STAP;
   
   jsetplot((d->xi[0]+d->rx*cos(d->angle1)),
	    (d->yi[0]+d->ry*sin(d->angle1)));
   while(d->angle1+=STAP,d->angle1<d->angle2)
   {
      jplot((d->xi[0]+d->rx*cos(d->angle1)),
	    (d->yi[0]+d->ry*sin(d->angle1)));
   }
}

void dotext(Plotdata *d)
{
   debug("Doing Text .... : %s",d->text);

   if( filter(d) > 0) return;
   
   setcolor(TEXTCOL,d->rgbcolor);
   settextattr((int)(d->angle1 / DEG2RAD),d->txthjst);
   
   setfont(TEXTPLAIN,10 + (d->theight/1000));
   
   jtext(d->xi[0],d->yi[0],d->text);
}

void openblock(Plotdata *d)
{  return; /* dummy */
}

void closeblock(void)
{  return; /* dummy */
}

void startgraphics()
{
#if (DEBUG <= 1)
   
   setdatarange(0,getxres());
   
   graphon();
   setcolor(BACKGRCOL,0xa090ff);
   
   setcolor(LINECOL,BLACK);
   setcolor(TEXTCOL,RED);
   
   clrmap();
#endif
}

void usage(char *basename, char *title)
{
   fprintf(stderr,"\n%s\n",title);
   
   fprintf(stderr,
	   "\n Usage  : %s [[options] <dxffile>]\n\n"
	   "   Options: -p <1-3>    : viewplane , 1=xy, 2=xz, 3=yz\n"
	   "            -v [-v ...] : give (lots of) debug information\n"
	   ,basename);
   endjgraphic();
   exit(1);
}

int main(int argc, char *argv[])
{
   char *title=
     "        *** PLOT DXFFORMATS (AUTOCAD-DRAWINGS) USING JAVA GRAPHICS ***\n"
     "             KL, Jan 1990; " VERSION " (Linux version); KL " MODDATE;

   char *basename=argv[0]; /* should be preserved from option parser */
   char dxfname[STRSIZE];
   int  x;
   int  viewp;
   
   jgraphic();
   
   viewp = 1; /* defaults */
   
   if(argc == 1)
   {
      printf("\n%s\n",title);
      printf("\nDXF input name (excl .dxf)         : "); scanf("%250s",dxfname);
      
      printf("\nViewplane 3D (1=xy,2=xz,3=yz)      : "); scanf("%1d",&viewp);
      while(fgetc(stdin) != '\n'); /* empty stdin buffer (linebuffer) */
      
   }
   else
   {  /* parse options */
      x=argc;
      while(--x>0)
      {
	 if(*argv[1]=='-')
	 {
	    switch(*(++argv[1]))
	    {
	     case 'p': if(argc <= 2) usage(basename,title);
	       sscanf(argv[2],"%d",&viewp);
	       ++argv; --argc; --x; break;
	     case 'v': verbose++; break;
	     default:  usage(basename,title);
	       break;
	    }
	    ++argv; --argc;
	 }
      }
      if(argc < 2)
	usage(basename,title);
      sscanf(argv[1],"%250s",dxfname);
   }
   
   startgraphics();
   startparser(dxfname,viewp);

   fprintf(stderr,"Press <RETURN> to exit ...\n");
   
   while(getchar() != '\n') sleep(1);
   
#if (DEBUG <= 1)
   graphoff();
#endif
   endjgraphic();
   exit(0);
}

==> dxf2fig-2.13.tar.gz: dxf2fig-2.13/dxfjplot.c <==
/*
 * DXF2FIG : Converter for Autocad DXF format to FIG format.
 * Aug 1990 : Atari ST and VAX/VMS version by KL
 * Nov 2003 : Modified for Linux and Xfig by KL
 * Copyright (c) 1990-2003 by Kees Lemmens
 *
 * This software is distributed under the Gnu Public License and as such
 * may be copied, redistributed and modified freely as long as the original
 * Copyright above is retained and as long as any software derived from
 * this is distributed under the Gnu Public License as well.  Use of this
 * software in any patented or closed source software is strictly
 * prohibited.
 * 
 * For more information see the GPL : http://www.gnu.org/licenses/gpl.txt
 * 
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <unistd.h>

/* This program uses a modified version of my good old hrgraph library that
 * supports floating point coordinates and changing the datarange, allowing
 * for much more detail than with the old integer based hrgraph library.
 * This jgraph library is however only available in Java and not in the
 * C-based Xaw version, while hrgraph is available for both. */

#include "jgraph.h"
#include "dxfstuff.h"

#define  STAP   0.1
extern   double sin(),cos();

/* Some global (static) variables */

/* End global variables */

#if (DEBUG > 2) /* disable graphics for debug or else debugger may hang */
#  define jdot(x,y)
#  define jplot(x,y)
#  define jsetplot(x,y)
#  define setstyle(s,t)
#endif

long lookupcolor(int color)
{
   switch(color)
    {
     case   0:  return BLACK;    // byblock or white
     case   1:  return RED;      // red
     case   2:  return YELLOW;   // yellow
     case   3:  return GREEN;    // green
     case   4:  return CYAN;     // cyan
     case   5:  return BLUE;     // blue
     case   6:  return MAGENTA;  // magenta
     case   7:  return BLACK;    // black
     case   8:  return WHITE;    // gray          
     case  15:  return WHITE;    // white
     default :  return BLACK;
   }
}

int lookupltype(int ltype)
{
   switch(ltype)
   {
    case  DXFSOLID    :  return SOLID;
    case  DXFDASHED   :  return DASHED;
    case  DXFDOTTED   :  return DOTTED;
    case  DXFDOTDASHED:  return DOTDASHED;
    default           :  return SOLID;
   }
}

int lookuphorjust(int txthjst)
{
   switch(txthjst)
   {
    case  0   :  return TEXTLEFT;
    case  1   :  return TEXTCENTER;
    case  2   :  return TEXTRIGHT;
    default   :  return TEXTLEFT;
   }
}

int getxres()
{
    return 400000;
}

int getyres()
{
   return 300000;
}

void dopoint(Plotdata *d)
{
   debug("Doing Dot ...");

   if( filter(d) > 0) return;
   
   setcolor(DOTCOL,d->rgbcolor);
   jdot(d->xi[0],d->yi[0]);
} 

void doline(Plotdata *d)
{
   debug("Doing Line ...");

   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);

   jsetplot(d->xi[0],d->yi[0]);
   jplot(d->xi[1],d->yi[1]);
}

void dopline(Plotdata *d)
{
   int t;
   
   debug("Doing Polyline with %d vertices, color %d, depth %d ...",
	 d->nrvrt,d->rgbcolor,d->depth);
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   jsetplot(d->xvrt[0],d->yvrt[0]);
   for(t=0;t<d->nrvrt;t++)
     jplot(d->xvrt[t],d->yvrt[t]);
}

void dosolid(Plotdata *d)
{
   debug("Doing Solid ...");

   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);

   jsetplot(d->xi[0],d->yi[0]);
   jplot(d->xi[1],d->yi[1]); jplot(d->xi[3],d->yi[3]);
   jplot(d->xi[2],d->yi[2]); jplot(d->xi[0],d->yi[0]);
}

void do3dface(Plotdata *d)
{
   debug("Doing 3DFace ....");
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   jsetplot(d->xi[0],d->yi[0]);
   jplot(d->xi[1],d->yi[1]); jplot(d->xi[2],d->yi[2]);
   jplot(d->xi[3],d->yi[3]); jplot(d->xi[0],d->yi[0]);
}

void docircle(Plotdata *d)
{  float x;

   debug("Doing Circle ....");
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   /* Note that this routine also plots ellipses in contrast with jcircle() ! */
   
   jsetplot((int)(d->xi[0]+d->rx),d->yi[0]);
   for(x=0;x<PI2;x+=STAP)
     jplot((d->xi[0]+d->rx*cos(x)),
	   (d->yi[0]+d->ry*sin(x)));
   jplot((d->xi[0]+d->rx),d->yi[0]);
}

void doarc(Plotdata *d)
{
   debug("Doing Arc ....");
   
   if( filter(d) > 0) return;
   
   setstyle(d->ltype,d->width);
   setcolor(LINECOL,d->rgbcolor);
   
   while(d->angle1>d->angle2)
     d->angle1-=PI2;
   d->angle2+=0.5*STAP;
   
   jsetplot((d->xi[0]+d->rx*cos(d->angle1)),
	    (d->yi[0]+d->ry*sin(d->angle1)));
   while(d->angle1+=STAP,d->angle1<d->angle2)
   {
      jplot((d->xi[0]+d->rx*cos(d->angle1)),
	    (d->yi[0]+d->ry*sin(d->angle1)));
   }
}

void dotext(Plotdata *d)
{
   debug("Doing Text .... : %s",d->text);

   if( filter(d) > 0) return;
   
   setcolor(TEXTCOL,d->rgbcolor);
   settextattr((int)(d->angle1 / DEG2RAD),d->txthjst);
   
   setfont(TEXTPLAIN,10 + (d->theight/1000));
   
   jtext(d->xi[0],d->yi[0],d->text);
}

void openblock(Plotdata *d)
{  return; /* dummy */
}

void closeblock(void)
{  return; /* dummy */
}

void startgraphics()
{
#if (DEBUG <= 1)
   
   setdatarange(0,getxres());
   
   graphon();
   setcolor(BACKGRCOL,0xa090ff);
   
   setcolor(LINECOL,BLACK);
   setcolor(TEXTCOL,RED);
   
   clrmap();
#endif
}

void usage(char *basename, char *title)
{
   fprintf(stderr,"\n%s\n",title);
   
   fprintf(stderr,
	   "\n Usage  : %s [[options] <dxffile>]\n\n"
	   "   Options: -p <1-3>    : viewplane , 1=xy, 2=xz, 3=yz\n"
	   "            -v [-v ...] : give (lots of) debug information\n"
	   ,basename);
   fprintf(stderr,filterhelp());
   
   endjgraphic();
   exit(1);
}

int main(int argc, char *argv[])
{
   char *title=
     "        *** PLOT DXFFORMATS (AUTOCAD-DRAWINGS) USING JAVA GRAPHICS ***\n"
     "             KL, Jan 1990; " VERSION " (Linux version); KL " MODDATE;

   char *basename=argv[0]; /* should be preserved from option parser */
   char dxfname[STRSIZE];
   int  x;
   int  viewp;
   char *filters=""; /* no filter */
   
   jgraphic();
   
#if DEBUG >= 2
   verbose = 2;
#endif
   
   viewp = 1; /* defaults */
   
   if(argc == 1)
   {
      printf("\n%s\n",title);
      printf("\nDXF input name (excl .dxf)         : "); scanf("%250s",dxfname);
      
      printf("\nViewplane 3D (1=xy,2=xz,3=yz)      : "); scanf("%1d",&viewp);
      while(fgetc(stdin) != '\n'); /* empty stdin buffer (linebuffer) */
      
   }
   else
   {  /* parse options */
      x=argc;
      while(--x>0)
      {
	 if(*argv[1]=='-')
	 {
	    switch(*(++argv[1]))
	    {
	     case 'p': if(argc <= 2) usage(basename,title);
	       sscanf(argv[2],"%d",&viewp);
	       ++argv; --argc; --x; break;
	     case 'i': if(argc <= 2) usage(basename,title);
	       filters = argv[2];
	       ++argv; --argc; --x; break;
	     case 'v': verbose++; break;
	     default:  usage(basename,title);
	       break;
	    }
	    ++argv; --argc;
	 }
      }
      if(argc < 2)
	usage(basename,title);
      sscanf(argv[1],"%250s",dxfname);
   }
   
   startgraphics();
   startparser(dxfname,viewp,filters);

   fprintf(stderr,"Press <RETURN> to exit ...\n");
   
   while(getchar() != '\n') sleep(1);
   
#if (DEBUG <= 1)
   graphoff();
#endif
   endjgraphic();
   exit(0);
}
